.. include:: ../BADGES.rst

.. _swmmtoolbox_documentation:

swmmtoolbox
===========

This is the home page for the 'swmmtoolbox'.

swmmtoolbox dumps text out of binary files created by the Storm Water Managment Model (SWMM) version 5+.

swmmtoolbox should work with Python 3.6+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   usage
   command_line
   function_summary
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
